---
icon: material/history
---

!!! tip "Tip / 提示"

    This changelog has the following 7 types of updates, each of which is represented by 7 different colors  
    此更新日志有以下 7 中类型的更新内容，分别用 7 中不同颜色来表示

    * 🟢 **Added / 新增**
    * 🔴 **Removed / 移除**
    * 🟡 **Changed / 变更**
    * 🔵 **Optimized / 优化**
    * 🟣 **Fixed / 修复**
    * 🟠 **Deprecated / 弃用**
    * 🟤 **Refactored / 重构**

--8<-- "CHANGELOG.md:14"
